@@ -11,6 +11,7 @@
 #' @param tail which tail to shade, 'left' (default) or 'right'
 #' @param linecolor color of density curve
 #' @param shading color of shaded region and boundaries
+#' @param annotate_area if TRUE (default), report the area of the shaded region
 #'
 #' @seealso \code{\link{ShadedDensityCenter}}
 #'
@@ -29,12 +30,14 @@ ShadedDensity <- function(frame, xvar, threshold, title,
                           ...,
                           tail="left",
                           linecolor = "darkgray",
-                          shading = "darkblue") {
-  frame <- check_frame_args_list(...,
-                                 frame = frame,
-                                 name_var_list = list(xvar = xvar),
-                                 title = title,
-                                 funname = "WVPlots::ShadedDensity")
+                          shading = "darkblue",
+                          annotate_area = TRUE) {
+  frame <- as.data.frame(frame)
+  check_frame_args_list(...,
+                        frame = frame,
+                        name_var_list = list(xvar = xvar),
+                        title = title,
+                        funname = "WVPlots::ShadedDensity")
   x <- NULL # used as a symbol, declare not an unbound variable
 
   # calculate the distribution by hand
@@ -57,13 +60,18 @@ ShadedDensity <- function(frame, xvar, threshold, title,
   xrange = max(dens$x)-min(dens$x)
   textx = threshold + sign*0.01*xrange
 
-  ggplot2::ggplot() +
+  plt = ggplot2::ggplot() +
     ggplot2::geom_line(data=densityframe, ggplot2::aes(x=x, y=density), color=linecolor) +
     ggplot2::geom_ribbon(data=densityframe, ggplot2::aes(x=x, ymin=0, ymax=tail), fill=shading, alpha=0.5) +
     ggplot2::geom_vline(xintercept=threshold, color=shading,  linetype=3) +
-    ggplot2::annotate("text", x=textx, y=texty, label=text, size=5, hjust="inward", vjust="bottom") +
     ggplot2::ggtitle(title) +
     ggplot2::xlab(xvar)
+
+  if(annotate_area) {
+    plt = plt + ggplot2::annotate("text", x=textx, y=texty, label=text, size=5, hjust="inward", vjust="bottom")
+  }
+
+  plt
 }
 
 #' Plot the distribution of a variable with a center region shaded
@@ -77,6 +85,7 @@ ShadedDensity <- function(frame, xvar, threshold, title,
 #' @param ...  no unnamed argument, added to force named binding of later arguments.
 #' @param linecolor color of density curve
 #' @param shading color of shaded region and boundaries
+#' @param annotate_area if TRUE (default), report the area of the shaded region
 #'
 #' @seealso \code{\link{ShadedDensity}}
 #' @examples
@@ -89,14 +98,16 @@ ShadedDensity <- function(frame, xvar, threshold, title,
 #'
 #' @export
 ShadedDensityCenter <- function(frame, xvar, boundaries, title,
-                          ...,
-                          linecolor = "darkgray",
-                          shading = "darkblue") {
-  frame <- check_frame_args_list(...,
-                                 frame = frame,
-                                 name_var_list = list(xvar = xvar),
-                                 title = title,
-                                 funname = "WVPlots::ShadedDensity")
+                                ...,
+                                linecolor = "darkgray",
+                                shading = "darkblue",
+                                annotate_area = TRUE) {
+  frame <- as.data.frame(frame)
+  check_frame_args_list(...,
+                        frame = frame,
+                        name_var_list = list(xvar = xvar),
+                        title = title,
+                        funname = "WVPlots::ShadedDensity")
   if(length(boundaries) != 2) {
     stop("The argument boundaries must be exactly length 2: c(min, max).")
   }
@@ -127,13 +138,18 @@ ShadedDensityCenter <- function(frame, xvar, boundaries, title,
 
   shaded <- NULL # don't look like an unbound reference
 
-  ggplot2::ggplot() +
+  plt =  ggplot2::ggplot() +
     ggplot2::geom_line(data=densityframe, ggplot2::aes(x=x, y=density), color=linecolor) +
     ggplot2::geom_ribbon(data=densityframe, ggplot2::aes(x=x, ymin=0, ymax=shaded), fill=shading, alpha=0.5) +
     ggplot2::geom_vline(data=bframe, aes(xintercept=boundaries), color=shading,  linetype=3) +
-    ggplot2::annotate("text", x=textx, y=texty, label=text, size=5, hjust="inward", vjust="bottom") +
     ggplot2::ggtitle(title) +
     ggplot2::xlab(xvar)
+
+  if(annotate_area) {
+    plt = plt + ggplot2::annotate("text", x=textx, y=texty, label=text, size=5, hjust="inward", vjust="bottom")
+  }
+
+ plt
 }
 
 
